--- old/usr/src/lib/libm/common/LD/hypotl.c	2019-06-06 20:38:16.332046856 +0000
+++ new/usr/src/lib/libm/common/LD/hypotl.c	2019-06-06 20:38:16.348902306 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -52,7 +53,7 @@
  *	hypot(x,y) is NAN if x or y is NAN.
  *
  * Accuracy:
- * 	hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
+ *      hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
  *	in the last place)
  */
 
@@ -64,10 +65,11 @@
 #define	k	0x7fff
 
 long double
-hypotl(long double x, long double y) {
+hypotl(long double x, long double y)
+{
 	long double t1, t2, y1, y2, w;
-	int *px = (int *) &x, *py = (int *) &y;
-	int *pt1 = (int *) &t1, *py1 = (int *) &y1;
+	int *px = (int *)&x, *py = (int *)&y;
+	int *pt1 = (int *)&t1, *py1 = (int *)&y1;
 	enum fp_direction_type rd;
 	int j, nx, ny, nz;
 
@@ -75,6 +77,7 @@
 	py[2] &= 0x7fff;
 	nx = px[2];		/* biased exponent of x and y */
 	ny = py[2];
+
 	if (ny > nx) {
 		w = x;
 		x = y;
@@ -82,13 +85,16 @@
 		nz = ny;
 		ny = nx;
 		nx = nz;
-	}			/* force nx >= ny */
+	}				/* force nx >= ny */
+
 	if (nx - ny >= 66)
 		return (x + y);	/* x / y >= 2**65 */
+
 	if (nx < 0x5ff3 && ny > 0x205b) {	/* medium x,y */
 		/* save and set RD to Rounding to nearest */
 		rd = __swap87RD(fp_nearest);
 		w = x - y;
+
 		if (w > y) {
 			pt1[2] = px[2];
 			pt1[1] = px[1];
@@ -107,8 +113,10 @@
 			t2 = x - t1;
 			x = sqrtl(t1 * y1 - (w * (-w) - (t2 * y1 + y2 * x)));
 		}
+
 		if (rd != fp_nearest)
-			__swap87RD(rd);	/* restore rounding mode */
+			__swap87RD(rd);		/* restore rounding mode */
+
 		return (x);
 	} else {
 		if (nx == k || ny == k) {	/* x or y is INF or NaN */
@@ -120,9 +128,11 @@
 			else
 				return (x + y);
 		}
+
 		if (ny == 0) {
 			if (y == 0.L || x == 0.L)
 				return (x + y);
+
 			pt1[2] = 0x3fff + 16381;
 			pt1[1] = 0x80000000;
 			pt1[0] = 0;
@@ -133,6 +143,7 @@
 			y *= t1;
 			return (y1 * hypotl(x, y));
 		}
+
 		j = nx - 0x3fff;
 		px[2] -= j;
 		py[2] -= j;
